@@ -1,5 +1,10 @@
 """
-    gitdata
+   ____ _ _   ____        _
+  / ___(_) |_|  _ \  __ _| |_ __ _
+ | |  _| | __| | | |/ _` | __/ _` |
+ | |_| | | |_| |_| | (_| | || (_| |
+  \____|_|\__|____/ \__,_|\__\__,_|
+
 """
 
 from .utils import Record
